@@ -7,7 +7,7 @@ import threading
 
 import requests
 
-__version__ = '1.4.4b'
+__version__ = '1.4.5b'
 
 class Event(object):
 	def __init__(self, connection):
@@ -152,11 +152,11 @@ class Client(object):
 			'lgpassword': password,
 			'format':'json'}
 		data = urllib.urlencode(login_data)
-		response = session.post(self.wiki + "/api.php",data=login_data)
+		response = self.session.post(self.wiki + "/api.php",data=login_data)
 		content = json.loads(response.content)
 		login_data['lgtoken'] = content['login']['token']
 		data = urllib.urlencode(login_data)
-		response = session.post(self.wiki + "/api.php",data=login_data)
+		response = self.session.post(self.wiki + "/api.php",data=login_data)
 		content = json.loads(response.content)
 		if content['login']['result'] != 'Success':
 			print 'Couldn\'t log in: Quitting.'
